@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ from ..enums.file_name_enum import FileNameEnum
 from ..enums.log_level_enum import LogLevelEnum
 from ..enums.segments.result_status import ResultStatus
 from ..helpers import validate_util, campaign_util
-from ..logger.logger_manager import VWOLogger
+from ..logger import VWOLogger
 from .bucketer import Bucketer
 from ..services.segmentor import SegmentEvaluator
 from ..constants import constants
@@ -34,19 +34,13 @@ class VariationDecider(object):
             UserStorage and logger.
 
         Args:
-            settings_file (dict): settings_file consisting all the campaign
-            related data
-            user_storage: Class instance having the capability of
+            user_storage (Class|None): Class instance having the capability of
                 get and set.
         """
         self.logger = VWOLogger.getInstance()
         self.bucketer = Bucketer()
         self.segment_evaluator = SegmentEvaluator()
-        # Check if user_storage provided is valid or not
-        if validate_util.is_valid_service(user_storage, 'user_storage'):
-            self.user_storage = user_storage
-        else:
-            self.user_storage = None
+        self.user_storage = user_storage
 
     def get_variation(self, user_id, campaign, **kwargs):
         """ Returns variation for the user for given campaign
@@ -72,9 +66,9 @@ class VariationDecider(object):
             assigned else None
         """
 
-        custom_variables = kwargs.get('custom_variables')
-        variation_targeting_variables = kwargs.get('variation_targeting_variables')
-
+        custom_variables = kwargs.get("custom_variables")
+        variation_targeting_variables = kwargs.get("variation_targeting_variables")
+        goal_data = kwargs.get("goal_data")
         # Evaluate whitelisting at first
         targeted_variation = self.find_targeted_variation(user_id, campaign, variation_targeting_variables)
         if targeted_variation:
@@ -82,33 +76,57 @@ class VariationDecider(object):
                 LogLevelEnum.INFO,
                 LogMessageEnum.INFO_MESSAGES.GOT_VARIATION_FOR_USER.format(
                     file=FILE,
-                    variation_name=targeted_variation.get('name'),
+                    variation_name=targeted_variation.get("name"),
                     user_id=user_id,
-                    campaign_key=campaign.get('key'),
-                    campaign_type=campaign.get('type')
-                )
+                    campaign_key=campaign.get("key"),
+                    campaign_type=campaign.get("type"),
+                ),
             )
             return targeted_variation
 
         # Try retrieving data from user_storage
-        variation = self.get_variation_from_user_storage(user_id, campaign)
-        if variation is not None:
-            return variation
+        user_storage_data = self._get_user_storage_data(user_id, campaign.get("key"))
+        if user_storage_data:
+            # If being called by track, check for goals identified
+            if goal_data:
+                is_goal_tracked = self.identify_tracked_goal_from_user_storage(goal_data, user_storage_data)
+                if is_goal_tracked:
+                    self.logger.log(
+                        LogLevelEnum.INFO,
+                        LogMessageEnum.INFO_MESSAGES.GOAL_ALREADY_TRACKED.format(
+                            file=FILE,
+                            goal_identifier=goal_data.get("identifier"),
+                            campaign_key=campaign.get("key"),
+                            user_id=user_id,
+                        ),
+                    )
+                    return None
+            # Retreving variation from user_storage_data
+            variation = self.get_variation_from_user_storage(user_id, campaign, user_storage_data)
+            # Setting goal information if variation found and api is track
+            if variation is not None:
+                if goal_data:
+                    self.update_goals_tracked_in_user_storage(goal_data, user_storage_data)
+                return variation
 
         # Evaluate pre-segmentation and percent-traffic
-        if self.evaluate_pre_segmentation(user_id, campaign, custom_variables) and \
-                self.is_user_part_of_campaign(user_id, campaign):
+        if self.evaluate_pre_segmentation(user_id, campaign, custom_variables) and self.is_user_part_of_campaign(
+            user_id, campaign
+        ):
             variation = self.bucketer.bucket_user_to_variation(user_id, campaign)
-            self._set_user_storage_data(user_id, campaign.get('key'), variation.get('name'))
+            new_user_storage_data = self._create_user_storage_data(
+                user_id, campaign.get("key"), variation.get("name"), goal_data=kwargs.get("goal_data")
+            )
+            self._set_user_storage_data(new_user_storage_data)
             self.logger.log(
                 LogLevelEnum.INFO,
                 LogMessageEnum.INFO_MESSAGES.GOT_VARIATION_FOR_USER.format(
                     file=FILE,
-                    variation_name=variation.get('name'),
+                    variation_name=variation.get("name"),
                     user_id=user_id,
-                    campaign_key=campaign.get('key'),
-                    campaign_type=campaign.get('type')
-                )
+                    campaign_key=campaign.get("key"),
+                    campaign_type=campaign.get("type"),
+                ),
             )
             return variation
 
@@ -116,15 +134,46 @@ class VariationDecider(object):
         self.logger.log(
             LogLevelEnum.INFO,
             LogMessageEnum.INFO_MESSAGES.USER_GOT_NO_VARIATION.format(
-                file=FILE,
-                user_id=user_id,
-                campaign_key=campaign.get('key'),
-                campaign_type=campaign.get('type')
-            )
+                file=FILE, user_id=user_id, campaign_key=campaign.get("key"), campaign_type=campaign.get("type")
+            ),
         )
         return None
 
-    def get_variation_from_user_storage(self, user_id, campaign):
+    def identify_tracked_goal_from_user_storage(self, goal_data, user_storage_data):
+        """ Identifies whether the given goal has been already tracked or not.
+
+        Args:
+            goal_data (dict): goal related data
+            user_storage_data (dict): data retrieved from user_storage
+
+        Returns:
+            bool: True if goal already tracked else False
+        """
+        goals_tracked = user_storage_data.get("goalIdentifiers")
+        if (
+            goals_tracked
+            and (goal_data.get("identifier") in goals_tracked.split("_vwo_"))
+            and not goal_data.get("should_track_returning_user")
+        ):
+            return True
+        return False
+
+    def update_goals_tracked_in_user_storage(self, goal_data, user_storage_data):
+        """ Updates the goals tracked information stored inside the user_storage service
+
+        Args:
+            goal_data (dict): the goal related data
+            user_storage_data (dict): new or retrieved user_storage_data
+        """
+        goals_tracked = user_storage_data.get("goalIdentifiers")
+        if goals_tracked:
+            updated_goals_tracked = goals_tracked + "_vwo_" + goal_data.get("identifier")
+        else:
+            updated_goals_tracked = goal_data.get("identifier")
+        user_storage_data["goalIdentifiers"] = updated_goals_tracked
+        self._set_user_storage_data(user_storage_data)
+
+    def get_variation_from_user_storage(self, user_id, campaign, user_storage_data):
         """ Tries retrieving variation from user_storage
 
         Args:
@@ -135,11 +184,9 @@ class VariationDecider(object):
             variation (dict|None): Dict object containing the information regarding variation
             assigned else None
         """
-
-        user_storage_data = self._get_user_storage_data(user_id, campaign.get('key'))
         if validate_util.is_valid_dict(user_storage_data):
-            if user_storage_data.get('campaignKey') == campaign.get('key'):
-                variation_name = user_storage_data.get('variationName')
+            if user_storage_data.get("campaignKey") == campaign.get("key"):
+                variation_name = user_storage_data.get("variationName")
                 if validate_util.is_valid_string(variation_name):
                     variation = campaign_util.get_campaign_variation(campaign, variation_name)
                     if variation:
@@ -147,19 +194,17 @@ class VariationDecider(object):
                             LogLevelEnum.INFO,
                             LogMessageEnum.INFO_MESSAGES.GOT_STORED_VARIATION.format(
                                 file=FILE,
-                                campaign_key=campaign.get('key'),
+                                campaign_key=campaign.get("key"),
                                 user_id=user_id,
-                                variation_name=variation.get('name')
-                            )
+                                variation_name=variation.get("name"),
+                            ),
                         )
                         return variation
         self.logger.log(
             LogLevelEnum.DEBUG,
             LogMessageEnum.DEBUG_MESSAGES.NO_STORED_VARIATION.format(
-                file=FILE,
-                campaign_key=campaign.get('key'),
-                user_id=user_id
-            )
+                file=FILE, campaign_key=campaign.get("key"), user_id=user_id
+            ),
         )
         return None
 
@@ -176,20 +221,18 @@ class VariationDecider(object):
             targeted_variation (dict|None): Dict object containing the information regarding forced
             variation assigned else None
         """
-        if campaign.get('isForcedVariationEnabled') is not True:
+        if campaign.get("isForcedVariationEnabled") is not True:
             self.logger.log(
                 LogLevelEnum.DEBUG,
                 LogMessageEnum.DEBUG_MESSAGES.WHITELISTING_SKIPPED.format(
-                    file=FILE,
-                    user_id=user_id,
-                    campaign_key=campaign.get('key'),
-                )
+                    file=FILE, user_id=user_id, campaign_key=campaign.get("key")
+                ),
             )
             return None
         else:
-            white_listed_variations_list = self._get_white_listed_variations_list(user_id,
-                                                                                  campaign,
-                                                                                  variation_targeting_variables)
+            white_listed_variations_list = self._get_white_listed_variations_list(
+                user_id, campaign, variation_targeting_variables
+            )
             white_listed_variations_len = len(white_listed_variations_list)
             if white_listed_variations_len == 0:
                 targeted_variation = None
@@ -204,19 +247,20 @@ class VariationDecider(object):
                 # Now retrieve the variation from the modified_campaign_for_whitelisting
                 bucket_value = self.bucketer.get_bucket_value_for_user(user_id, constants.MAX_TRAFFIC_VALUE)
                 targeted_variation = self.bucketer.get_variation(white_listed_variations_list, bucket_value)
-            variation_status = 'and variation {variation_name} is assigned'
+            variation_status = "and variation {variation_name} is assigned"
             self.logger.log(
                 LogLevelEnum.INFO,
                 LogMessageEnum.INFO_MESSAGES.SEGMENTATION_STATUS.format(
                     file=FILE,
-                    campaign_key=campaign.get('key'),
+                    campaign_key=campaign.get("key"),
                     user_id=user_id,
                     variables=variation_targeting_variables,
-                    variation_status=variation_status.format(variation_name=targeted_variation.get('name')
-                                                             if targeted_variation else None),
-                    segmentation_type='whitelisting',
-                    status=ResultStatus.PASSED if targeted_variation is not None else ResultStatus.FAILED
-                )
+                    variation_status=variation_status.format(
+                        variation_name=targeted_variation.get("name") if targeted_variation else None
+                    ),
+                    segmentation_type="whitelisting",
+                    status=ResultStatus.PASSED if targeted_variation is not None else ResultStatus.FAILED,
+                ),
             )
             return targeted_variation
 
@@ -232,7 +276,7 @@ class VariationDecider(object):
         Returns:
             bool: True if user passes segmentation, else False
         """
-        segments = campaign.get('segments')
+        segments = campaign.get("segments")
         if not validate_util.is_valid_value(segments):
             result = True
             self.logger.log(
@@ -240,10 +284,10 @@ class VariationDecider(object):
                 LogMessageEnum.DEBUG_MESSAGES.SEGMENTATION_SKIPPED.format(
                     file=FILE,
                     user_id=user_id,
-                    campaign_key=campaign.get('key'),
+                    campaign_key=campaign.get("key"),
                     variables=custom_variables,
-                    variation_status=''
-                )
+                    variation_status="",
+                ),
             )
         else:
             if not validate_util.is_valid_value(custom_variables):
@@ -252,9 +296,9 @@ class VariationDecider(object):
                     LogMessageEnum.DEBUG_MESSAGES.NO_VARIABLES.format(
                         file=FILE,
                         user_id=user_id,
-                        campaign_key=campaign.get('key'),
-                        segmentation_type='pre_segmentation'
-                    )
+                        campaign_key=campaign.get("key"),
+                        segmentation_type="pre_segmentation",
+                    ),
                 )
                 custom_variables = {}
             try:
@@ -264,12 +308,12 @@ class VariationDecider(object):
                     LogMessageEnum.INFO_MESSAGES.SEGMENTATION_STATUS.format(
                         file=FILE,
                         user_id=user_id,
-                        campaign_key=campaign.get('key'),
+                        campaign_key=campaign.get("key"),
                         variables=custom_variables,
-                        variation_status='',
-                        segmentation_type='pre_segmentation',
-                        status=ResultStatus.PASSED if result else ResultStatus.FAILED
-                    )
+                        variation_status="",
+                        segmentation_type="pre_segmentation",
+                        status=ResultStatus.PASSED if result else ResultStatus.FAILED,
+                    ),
                 )
             except Exception as e:
                 result = False
@@ -278,11 +322,11 @@ class VariationDecider(object):
                     LogMessageEnum.ERROR_MESSAGES.SEGMENTATION_ERROR.format(
                         file=FILE,
                         user_id=user_id,
-                        campaign_key=campaign.get('key'),
+                        campaign_key=campaign.get("key"),
                         variables=custom_variables,
-                        variation_status='',
+                        variation_status="",
                         error_message=e,
-                    )
+                    ),
                 )
         return result
 
@@ -299,7 +343,7 @@ class VariationDecider(object):
         """
 
         if self.bucketer.is_user_part_of_campaign(user_id, campaign):
-           return True
+            return True
         else:
             # not part of campaign
             self.logger.log(
@@ -307,10 +351,10 @@ class VariationDecider(object):
                 LogMessageEnum.DEBUG_MESSAGES.USER_NOT_PART_OF_CAMPAIGN.format(
                     file=FILE,
                     user_id=user_id,
-                    campaign_key=campaign.get('key'),
-                    method='is_user_part_of_campaign',
-                    campaign_type=campaign.get('type')
-                )
+                    campaign_key=campaign.get("key"),
+                    method="is_user_part_of_campaign",
+                    campaign_type=campaign.get("type"),
+                ),
             )
             return False
 
@@ -331,44 +375,41 @@ class VariationDecider(object):
             self.logger.log(
                 LogLevelEnum.DEBUG,
                 LogMessageEnum.DEBUG_MESSAGES.NO_VARIABLES.format(
-                    file=FILE,
-                    user_id=user_id,
-                    campaign_key=campaign.get('key'),
-                    segmentation_type='whitelisting'
-                )
+                    file=FILE, user_id=user_id, campaign_key=campaign.get("key"), segmentation_type="whitelisting"
+                ),
             )
             variation_targeting_variables = {}
 
         variation_targeting_variables.update(_vwo_user_id=user_id)
         white_listed_variations_list = []
 
-        for variation in campaign.get('variations'):
-            if not validate_util.is_valid_value(variation.get('segments')):
+        for variation in campaign.get("variations"):
+            if not validate_util.is_valid_value(variation.get("segments")):
                 result = False
                 self.logger.log(
                     LogLevelEnum.DEBUG,
                     LogMessageEnum.DEBUG_MESSAGES.SEGMENTATION_SKIPPED.format(
                         file=FILE,
                         user_id=user_id,
-                        variation_name=variation.get('name'),
-                        campaign_key=campaign.get('key'),
-                        variation_status='for variation %s' % variation.get('name')
-                    )
+                        variation_name=variation.get("name"),
+                        campaign_key=campaign.get("key"),
+                        variation_status="for variation %s" % variation.get("name"),
+                    ),
                 )
             else:
                 try:
-                    result = self.segment_evaluator.evaluate(variation.get('segments'), variation_targeting_variables)
+                    result = self.segment_evaluator.evaluate(variation.get("segments"), variation_targeting_variables)
                     self.logger.log(
                         LogLevelEnum.DEBUG,
                         LogMessageEnum.DEBUG_MESSAGES.SEGMENTATION_STATUS.format(
                             file=FILE,
                             user_id=user_id,
-                            status='passed' if result else 'failed',
+                            status="passed" if result else "failed",
                             variables=variation_targeting_variables,
-                            variation_status='for variation %s' % variation.get('name'),
-                            campaign_key=campaign.get('key'),
-                            segmentation_type='white_listing'
-                        )
+                            variation_status="for variation %s" % variation.get("name"),
+                            campaign_key=campaign.get("key"),
+                            segmentation_type="white_listing",
+                        ),
                     )
                 except Exception as e:
                     result = False
@@ -378,15 +419,35 @@ class VariationDecider(object):
                             file=FILE,
                             user_id=user_id,
                             variables=variation_targeting_variables,
-                            campaign_key=campaign.get('key'),
-                            variation_status=' for variation %s' % variation.get('name'),
+                            campaign_key=campaign.get("key"),
+                            variation_status=" for variation %s" % variation.get("name"),
                             error_message=e,
-                        )
+                        ),
                     )
             if result:
                 white_listed_variations_list.append(copy.deepcopy(variation))
         return white_listed_variations_list
 
+    def _create_user_storage_data(self, user_id, campaign_key, variation_name, **kwargs):
+        """ Creates a user_storage_data object to be set by user_storage service implemented by user
+
+        Args:
+            user_id (str): unique user ID
+            campaign_key (str): campaign key
+            variation_name (str): winner of the campaign
+
+        Keyword Args:
+            goal_data (dict): goal related data if track api being called
+
+        Returns:
+            dict: a user_storage_data object with specified properties
+        """
+        new_user_storage_data = {"userId": user_id, "campaignKey": campaign_key, "variationName": variation_name}
+        # For track only, to store the goals tracked
+        if kwargs.get("goal_data"):
+            new_user_storage_data["goalIdentifiers"] = kwargs.get("goal_data").get("identifier")
+        return new_user_storage_data
+
     def _get_user_storage_data(self, user_id, campaign_key):
         """ Get the UserStorageData after looking up into get method
         being provided via UserStorage service
@@ -399,34 +460,23 @@ class VariationDecider(object):
         """
 
         if not self.user_storage:
-            self.logger.log(
-                LogLevelEnum.DEBUG,
-                LogMessageEnum.DEBUG_MESSAGES.NO_USER_STORAGE_GET.format(
-                    file=FILE
-                )
-            )
+            self.logger.log(LogLevelEnum.DEBUG, LogMessageEnum.DEBUG_MESSAGES.NO_USER_STORAGE_GET.format(file=FILE))
             return False
         try:
             user_storage_data = self.user_storage.get(user_id, campaign_key)
             self.logger.log(
                 LogLevelEnum.INFO,
-                LogMessageEnum.INFO_MESSAGES.LOOKING_UP_USER_STORAGE.format(
-                    file=FILE,
-                    user_id=user_id
-                )
+                LogMessageEnum.INFO_MESSAGES.LOOKING_UP_USER_STORAGE.format(file=FILE, user_id=user_id),
             )
             return copy.deepcopy(user_storage_data)
         except Exception:
             self.logger.log(
                 LogLevelEnum.ERROR,
-                LogMessageEnum.ERROR_MESSAGES.LOOK_UP_USER_STORAGE_FAILED.format(
-                    file=FILE,
-                    user_id=user_id
-                )
+                LogMessageEnum.ERROR_MESSAGES.LOOK_UP_USER_STORAGE_FAILED.format(file=FILE, user_id=user_id),
             )
             return False
 
-    def _set_user_storage_data(self, user_id, campaign_key, variation_name):
+    def _set_user_storage_data(self, user_storage_data):
         """ If UserStorage is provided and variation was found,
         set the assigned variation in UserStorage.
             It creates bucket and then stores.
@@ -441,37 +491,23 @@ class VariationDecider(object):
         """
 
         if not self.user_storage:
-            self.logger.log(
-                LogLevelEnum.DEBUG,
-                LogMessageEnum.DEBUG_MESSAGES.NO_USER_STORAGE_SET.format(
-                    file=FILE
-                )
-            )
+            self.logger.log(LogLevelEnum.DEBUG, LogMessageEnum.DEBUG_MESSAGES.NO_USER_STORAGE_SET.format(file=FILE))
             return False
 
-        new_user_storage_data = {
-            "userId": user_id,
-            "campaignKey": campaign_key,
-            "variationName": variation_name
-        }
         try:
-            self.user_storage.set(new_user_storage_data)
+            self.user_storage.set(user_storage_data)
             self.logger.log(
                 LogLevelEnum.INFO,
                 LogMessageEnum.INFO_MESSAGES.SAVING_DATA_USER_STORAGE_STATUS.format(
-                    file=FILE,
-                    user_id=user_id,
-                    status='successful'
-                )
+                    file=FILE, user_id=user_storage_data.get("userId"), status="successful"
+                ),
             )
             return True
         except Exception as e:
             self.logger.log(
                 LogLevelEnum.ERROR,
                 LogMessageEnum.ERROR_MESSAGES.SET_USER_STORAGE_FAILED.format(
-                    file=FILE,
-                    user_id=user_id,
-                    error_message=e
-                )
+                    file=FILE, user_id=user_storage_data.get("userId"), error_message=e
+                ),
             )
             return False
