@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@ from ..http.connection import Connection
 from ..enums.log_message_enum import LogMessageEnum
 from ..enums.file_name_enum import FileNameEnum
 from ..enums.log_level_enum import LogLevelEnum
-from ..logger.logger_manager import VWOLogger
+from ..logger import VWOLogger
 
 FILE = FileNameEnum.Event.EventDispatcher
 
@@ -35,41 +35,31 @@ class EventDispatcher(object):
         self.is_development_mode = is_development_mode
         self.connection = Connection()
 
-    # The method dispatch has references from "Optimizely Python SDK, version 3.2.0",
-    # Copyright 2016-2019, Optimizely, used under Apache 2.0 License.
-    # Source - https://github.com/optimizely/python-sdk/blob/master/optimizely/event_dispatcher.py
     def dispatch(self, impression):
-        """ Dispatch the event represented by the impression object.
+        """ This method checks for development mode, if it is False then it sends the impression
+        to our servers using a vwo.http.connection.Connection object, else return True without
+        sending the impression.
 
         Args:
-            event (dict): Object holding information about
-            he request to be dispatched to the VWO backend.
+            impression (dict): Dictionary object containing the information of the impression
 
         Returns:
-            bool: True for success, false for failure
+            bool: True if impression is successfully received by our servers, else false
         """
-        url = impression.pop('url')
+        url = impression.pop("url")
         if self.is_development_mode:
             result = True
         else:
             resp = self.connection.get(url, params=impression)
-            result = resp.get('status_code') == 200
+            result = resp.get("status_code") == 200
 
         if result is True:
             self.logger.log(
-                LogLevelEnum.INFO,
-                LogMessageEnum.INFO_MESSAGES.IMPRESSION_SUCCESS.format(
-                    file=FILE,
-                    end_point=url,
-                )
+                LogLevelEnum.INFO, LogMessageEnum.INFO_MESSAGES.IMPRESSION_SUCCESS.format(file=FILE, end_point=url)
             )
             return True
         else:
             self.logger.log(
-                LogLevelEnum.ERROR,
-                LogMessageEnum.ERROR_MESSAGES.IMPRESSION_FAILED.format(
-                    file=FILE,
-                    end_point=url,
-                )
+                LogLevelEnum.ERROR, LogMessageEnum.ERROR_MESSAGES.IMPRESSION_FAILED.format(file=FILE, end_point=url)
             )
             return False
