@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +18,10 @@ import sys
 import json
 import jsonschema
 from ..schemas.settings_file_schema import SETTINGS_FILE_SCHEMA
+from ..constants.constants import LOG_LEVELS, GOAL_TYPES
+from . import generic_util
 
-services = {
-    'logger': ['log'],
-    'event_dispatcher': ['dispatch'],
-    'user_storage': ['get', 'set']
-}
+services = {"logger": ["log"], "event_dispatcher": ["dispatch"], "user_storage": ["get", "set"]}
 
 
 def is_valid_settings_file(settings_file):
@@ -35,25 +33,21 @@ def is_valid_settings_file(settings_file):
             must be json string representation.
 
     Returns:
-        bool: Whether the settings file is valid or not
+        bool: Whether the settings_file is valid or not
     """
     try:
         settings_file = json.loads(settings_file)
     except Exception:
         return False
     try:
-        jsonschema.validate(
-            instance=settings_file,
-            schema=SETTINGS_FILE_SCHEMA
-        )
+        jsonschema.validate(instance=settings_file, schema=SETTINGS_FILE_SCHEMA)
     except Exception:
         return False
     return True
 
 
 def is_valid_service(service, service_name):
-    """ Checks whether the service passed by the user
-        contains the necessary methods or not
+    """ Checks whether the service passed by the user contains the necessary methods or not
 
     Args:
         service (classobj): User defined class instance
@@ -72,47 +66,111 @@ def is_valid_service(service, service_name):
 
 
 def is_valid_log_level(level):
-    string_levels = [
-        'CRITICAL',
-        'FATAL',
-        'ERROR',
-        'WARN',
-        'WARNING',
-        'INFO',
-        'DEBUG',
-        'NOTSET',
-    ]
-    if isinstance(level, str) and level not in string_levels:
-        return False
-    else:
-        return is_valid_number(level)
+    """ Validates if the value passed is lies inside the vwo.enums.LogLevelEnum enum or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if valid LOG_LEVEL else False
+    """
+    return level in generic_util.get_attribute_values(LOG_LEVELS)
+
+
+def is_valid_goal_type(goal_type):
+    """ Validates if the value passed is lies inside the vwo.constants.GOAL_TYPE enum or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if valid GOAL_TYPE else False
+    """
+    return goal_type in generic_util.get_attribute_values(GOAL_TYPES)
 
 
 def is_valid_dict(val):
+    """ Validates if the value passed is of dict type or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if dict else False
+    """
     return type(val) is dict
 
 
 def is_valid_value(val):
+    """ Validates if the value passed is a valid value,
+    note: None is a valid value
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if not None and bool(val) is True else False
+    """
     return val is not None and bool(val)
 
 
 def is_valid_non_zero_number(val):
+    """ Validates if the value passed is a number & it is non zero.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if nonzero number else False
+    """
     return type(val) == int and is_valid_value(val)
 
 
 def is_valid_number(val):
+    """ Validates if the value passed is a number(int/float) or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if number else False
+    """
     return type(val) == int
 
 
 def is_valid_unicode(val):
+    """ Validates if the value passed is a python unicode value or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if unicode else False
+    """
     if sys.version_info[0] < 3:
         return type(val) is unicode
     return False
 
 
 def is_valid_string(val):
+    """ Validates if the value passed is a valid python str or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if string else False
+    """
     return (type(val) == str or is_valid_unicode(val)) and is_valid_value(val)
 
 
-def is_valid_basis_data_type(val):
+def is_valid_basic_data_type(val):
+    """ Validates if the value passed is of basic data type or not.
+
+    Args:
+        val (any type): value to be tested
+
+    Returns:
+        bool: True if basic data type else False
+    """
     return type(val) in [int, float, bool, str]
