@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,23 +13,9 @@
 # limitations under the License.
 
 GOAL = {
-    'items': {
-        'type': 'object',
-        'properties': {
-            'identifier': {
-                'type': 'string'
-            },
-            'id': {
-                'type': 'number'
-            },
-            'type': {
-                'type': 'string'
-            }
-        },
-        'required': [
-            'identifier',
-            'id',
-            'type'
-        ]
+    "items": {
+        "type": "object",
+        "properties": {"identifier": {"type": "string"}, "id": {"type": "number"}, "type": {"type": "string"}},
+        "required": ["identifier", "id", "type"],
     }
 }
