@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,12 +14,12 @@
 
 
 class UserStorage(object):
-    ''' UserStorage Class is used to store user-variation mapping.
+    """ UserStorage Class is used to store user-variation mapping.
     Override this class to implement your own functionality.
-    SDK will ensure to use this while bucketing a user into a variation.'''
+    SDK will ensure to use this while bucketing a user into a variation."""
 
     def get(self, user_id, campaign_key):
-        ''' To retrieve the stored variation for the user_id and
+        """ To retrieve the stored variation for the user_id and
         campaign_key
 
         Args:
@@ -29,13 +29,13 @@ class UserStorage(object):
 
         Returns:
             user_data (dict): user-variation mapping
-        '''
+        """
         pass
 
     def set(self, user_data):
-        ''' To store the the user variation-mapping
+        """ To store the the user variation-mapping
 
         Args:
             user_data (dict): user-variation mapping
-        '''
+        """
         pass
